==> hashikake-0.1.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/Main.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		Main.java
//	DATE:		2003.5.27
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator;

import java.awt.Frame;

import jp.gr.java_conf.ktz.puzzle.framework.StateManager;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.model.HashiCreStateManagerImpl;
import jp.gr.java_conf.ktz.puzzle.hashikake.creator.model.SelectStateManagerImpl;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.HashiCreatorRoot;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.BoardView;

/**
 *	̃vOentry point
 */
public class Main {
	public static void main(String[] inArgs) {
		// StateManageȑ
		StateManager.initialize(new SelectStateManagerImpl(new HashiCreStateManagerImpl()));

		HashiCreatorRoot.showRootBoard();
	}
}

==> hashikake-0.3.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/Main.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		Main.java
//	DATE:		2003.5.27
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator;

import jp.gr.java_conf.ktz.puzzle.framework.StateManager;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.model.HashiCreStateManagerImpl;
import jp.gr.java_conf.ktz.puzzle.hashikake.creator.model.SelectStateManagerImpl;

import jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.HashiCreatorRoot;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.Bundle;
import jp.gr.java_conf.ktz.puzzle.hashikake.util.PropertyBundle;
import jp.gr.java_conf.ktz.puzzle.hashikake.util.ResourceLoader;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.gui.MenuManager;

/**
 *	̃vOentry point
 */
public class Main {
	private static final String MENU_RESOURCE_KEY = "menu_info_resource";
	private static final String LOCALIZE_RESOURCE_KEY = "localize_resource";
	
	static {
		String aPath = Bundle.getString(LOCALIZE_RESOURCE_KEY);
		java.net.URL aResource = ResourceLoader.loadProperty(Main.class, aPath);
		PropertyBundle.initialize(aResource);
	}
	
	public static void main(String[] inArgs) {
		// StateManageȑ
		StateManager.initialize(new SelectStateManagerImpl(new HashiCreStateManagerImpl()));
		
		// menu resourceload
		String aPath = Bundle.getString(MENU_RESOURCE_KEY);
		java.net.URL aResource = ResourceLoader.loadResource(Main.class, aPath);
		MenuManager.initMenuBarInfo(aResource);
		
		// frame̕\
		HashiCreatorRoot.showRootBoard();
	}
}
